#!/usr/bin/wish8.4

set gtversion "v1.7.0 (28 May 2013)"


if {$tcl_platform(platform) == "windows"} { lappend auto_path extlibs }
lappend auto_path lib/BWidget-1.9.2

package require BWidget 1.9
# package require Img

source init/init.tcl
source init/defaults.tcl
source data/malts.tcl
source init/userdata.tcl ;# hops, grain, and malt added by user
source init/config.tcl   ;# user configuration for mash specs, etc.

set invok 0
if {[string length $dbhome] && [file isdirectory $dbhome]} {
   if {[file exists $dbhome/inventory.db]} {
      set invok 1
      source lib/db.tcl
      source lib/mk_hops.tcl
      source lib/client.tcl
   }
}
if {!$invok} { file copy -force data/nodb_hops.tcl data/hops.tcl }



source data/hops.tcl
source data/styles.tcl
# source data/yeastidx.tcl ;# not used
source lib/grainprocs.tcl
source lib/menuprocs.tcl
source lib/maths.tcl
source lib/styledata.tcl
source lib/stepmash.tcl
source lib/balloonhelp.tcl
source lib/string.tcl
source lib/saveload.tcl
source lib/savestat.tcl
source lib/mapnames.tcl
if {!$invok} { load_invdb }

proc debug {s} { set f [open debug.out a] ; puts $f $s ; close $f }

proc strlen {s} { return [string length $s] }

proc getstyledata {args} {
   global stylename ogmin ogmax fgmin fgmax srmmin srmmax ibumin ibumax
   global ogrange fgrange srmrange iburange savestyledata snum Style styles

   set savestyledata "set snum \"$snum\" ; getstyledata $args"

   foreach arg $args {
      if {[regexp {refer_to_base} $arg]} {
         tk_messageBox -type ok -message \
            "The ranges for OG, FG, Color, and Bitterness are taken from the base style upon which this specialty style is based."
            set ogmin 1.000 ; set ogmax 1.130 ; set srmmin 0; set srmmax 100
            set ibumin 0 ; set ibumax 100 ; set ogrange 1.000-100
            set fgmin 1.000 ; set fgmax 1.022 ; set fgrange 1.000-22
            set srmrange 0-100 ; set iburange 0-100
            if {$snum == 21} { set name $snum[lindex $args 0]
            } else { set i $snum ; incr i -1 ; set name [lindex $styles() $i]
            }
            set Style $name
            return
      }
   }

   foreach {name og fg abv sibu srm} $args { break }
   regsub -all {_} $name { } stylename
   set Style "$snum$stylename"



   set bad 0
   if {![regexp {^([0-9.]*)-([0-9.]*)$} $og a ogmin ogmax]} { set bad 1 }
   if {![regexp {^([0-9.]*)-([0-9.]*)$} $fg a fgmin fgmax]} { set bad 1 }
   if {[regexp {^[1-9][0-9]$} $ogmin]} { set ogmin "1.0$ogmin" }
   if {[regexp {^[1-9][0-9]$} $ogmax]} { set ogmax "1.0$ogmax" }
   if {[regexp {^[1-9][0-9]$} $fgmin]} { set fgmin "1.0$fgmin" }
   if {[regexp {^[1-9][0-9]$} $fgmax]} { set fgmax "1.0$fgmax" }
   if {![regexp {^([0-9.]*)-([0-9.]*)$} $srm a srmmin srmmax]} { set bad 1 }
   if {![regexp {^([0-9.]*)-([0-9.]*)$} $sibu a ibumin ibumax]} { set bad 1 }
   if {$bad} { tk_messageBox -type ok -message "Trouble reading data for $name" }
   set ogrange $og
   set fgrange $fg
   set srmrange $srm
   set iburange $sibu
}

pack [frame .mf] -side top -expand y -fill x

set m .mf
menubutton $m.file -text "File" -menu $m.file.m
menu $m.file.m -tearoff 0
$m.file.m add command -label Console -command { toggle_tkcon }

$m.file.m add command -label "New recipe (clears current)" \
   -command clearbrew
$m.file.m add command -label "Load recipe from file" -command loadbrew
$m.file.m add command -label "Save recipe to file" -command savebrew
if {$invok} {
   $m.file.m add command -label "Mark grains/hops as USED in inventory" \
      -command {use_reserve 1}
   $m.file.m add command -label "Mark grains/hops as RESERVED in inventory" \
      -command {use_reserve 2}
   $m.file.m add command -label "CLEAR reservation on grains/hops in inventory" \
      -command {use_reserve 3}
}
$m.file.m add command -label "Save recipe report" -command make_report
$m.file.m add command -label "Save recipe report (TeX)" -command make_report_TeX
$m.file.m add command -label "Exit" -command { exit }

button $m.opts -text "Configuration" -command {newconfig} -relief flat


menubutton $m.bjcp -text "Select style" -menu $m.bjcp.m
menu $m.bjcp.m -tearoff 0
$m.bjcp.m add command -label "Major Style Categories"
foreach ms $styles() {
   if {[regexp {^([1-9][0-9]*)._(.*)$} $ms a idnum desc]} {
      set msm $m.bjcp.m.maj$idnum
      $m.bjcp.m add cascade -label "$ms" -menu $msm
      menu $msm
      foreach style $styles($ms) {
         foreach {name og fg abv ibu srm} $style { break }
         regsub -all {_} $name { } nameb
         regexp {^([0-9]*)[^0-9]*} $ms a msnum
         $msm add command -label $nameb \
            -command "set snum $msnum ; getstyledata $style "
      }
   }
}


menubutton $m.cnvrt -text "Utils and Conversions" -menu $m.cnvrt.m
menu $m.cnvrt.m -tearoff 0 -disabledforeground  #cc0000
$m.cnvrt.m add command -label "Recipe Reformulation" -command reformulate
$m.cnvrt.m add command -label "Step Mash Calcs" -command full_stepmash
$m.cnvrt.m add command -label "Carbonation pressure" \
   -command { get_co2_info }
$m.cnvrt.m add command -label "SG to Plato" -command { gi SG_to_Plato SG "P" }
$m.cnvrt.m add command -label "Plato to SG" -command { gi Plato_to_SG P SG }
$m.cnvrt.m add separator
$m.cnvrt.m add command -label "unit conversions" -state disabled \
   -command {}
$m.cnvrt.m add separator
$m.cnvrt.m add command -label "C to F"  -command \
   { gi CtoF "C" "F" }
$m.cnvrt.m add command -label "F to C"  -command \
   { gi FtoC "F" "C" }
$m.cnvrt.m add command -label "lbs to kg"         -command \
   { gi lbs_to_kg lbs kg }
$m.cnvrt.m add command -label "kg to lbs"         -command \
   { gi kg_to_lbs kg lbs }
$m.cnvrt.m add command -label "gallons to liters" -command \
   { gi gal_to_ltr gallons liters }
$m.cnvrt.m add command -label "liters to gallons" -command \
   { gi ltr_to_gal liters gallons }
$m.cnvrt.m add command -label "quarts to liters"  -command \
   { gi qts_to_ltr quarts liters }
$m.cnvrt.m add command -label "liters to quarts"  -command \
   { gi ltr_to_qts liters quarts }


menubutton $m.data -text "Style/Product Info" -menu $m.data.m
menu $m.data.m -tearoff 0
$m.data.m add command -label "BJCP Style Guides" -command get_bjcp_info
$m.data.m add command -label "Yeast Strain Data" -command get_yeast_info
$m.data.m add command -label "Grain Data" -command get_grain_info
$m.data.m add command -label "Hop Data" -command get_hop_info
$m.data.m add command -label "Add New Hop Data" -command get_new_hop_info

button $m.comments -text {[Comments]} -command get_comments -relief flat

pack $m.file $m.opts $m.bjcp $m.cnvrt $m.data $m.comments -side left -anchor w

button $m.bexit -text "\[Exit]" -command {exit} -relief flat
pack $m.bexit -side right -anchor e

canvas .c -background white -width 1024 -height 580
pack .c -side top
# image create photo logsheet -file gtlog2.jpg
# set logid [.c create image 0 0 -image logsheet -anchor nw]

set i 0
#  bind .c <1> {
#     incr i
#     puts "$i:  x=%x  y=%y"
#     .c create text %x %y -text \[$i] -anchor w
#     update
#  }

source lib/logsheet.tcl

wm title . "GTbrew2 $gtversion"
wm geometry . +0+0
wm protocol . WM_DELETE_WINDOW { exit }
source lib/tkcon_wrap.tcl

set brewchanged 0
set format "%a %d %h %Y %H:%M:%S"
set last_sec 90 ; set last_hour 90
while {1} {
   after 100 ;
   set t [clock seconds]
   set datetime [clock format $t -format $format]
   set dateonly [clock format $t -format "%a %d %h %Y"]
   set sec [clock format $t -format "%S"]
   if {$sec != $last_sec} {
      checkdilu
      checkeff
      checkogfg
   }
   set last_sec $sec

   catch { update }
}



